@@ -1,11 +1,10 @@
 // create a combo box for language definition file selections
-languageComboBox = 
-  new srchiliteqt::LanguageComboBox(textEdit->getHighlighter());
+languageComboBox = new srchiliteqt::LanguageComboBox();
 languageToolBar = addToolBar(tr("Language"));
 languageToolBar->addWidget(languageComboBox);
 // retrieve the current language by the text editor highlighter
 languageComboBox->setCurrentLanguage
-  (textEdit->getHighlighter()->getLangFile());
+    (textEdit->getHighlighter()->getLangFile());
 // and connect it to our text editor
 textEdit->connectLanguageComboBox(languageComboBox);
 
@@ -13,4 +12,6 @@ styleComboBox = new srchiliteqt::StyleComboBox;
 styleToolBar = addToolBar(tr("Style"));
 styleToolBar->addWidget(styleComboBox);
 styleComboBox->setCurrentStyle("default.style");
+// each time we insert something it will be resized
+styleComboBox->setSizeAdjustPolicy(QComboBox::AdjustToContents);
 textEdit->connectStyleComboBox(styleComboBox);
