@@ -1,5 +1,10 @@
+/*
+ *  Copyright (C) 2008-2010  Lorenzo Bettini, http://www.lorenzobettini.it
+ *  License: See COPYING file that comes with this distribution
+ */
+
 #include "SourceHighlightSettingsDialog.h"
-#include "SourceHighlightSettingsDialog.ui.h"
+#include "ui_SourceHighlightSettingsDialog.h"
 
 namespace srchiliteqt {
 
