@@ -12,6 +12,12 @@
 #include <QMainWindow>
 #include <QTextEdit>
 
+#include <iostream>
+
+#ifndef BASEDIR
+#define BASEDIR "./"
+#endif
+
 int main(int argc, char **argv) {
     QApplication app(argc, argv);
 
@@ -21,8 +27,10 @@ int main(int argc, char **argv) {
 
     if (argc > 1)
         highlighter->init(argv[1]);
-    else
+    else {
+        std::cout << "using " << BASEDIR "simple.lang" << std::endl;
         highlighter->init(BASEDIR "simple.lang");
+    }
 
     QMainWindow win(0);
     win.setCentralWidget(editor);
